/**
 * The geometry node for a cone.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglCone extends jooglGeometry{
    /** The radius of the base of the cone. */
    protected double radius;
    /** The height of the cone. */
    protected double height;
    
    /** The number of slices in the base of the cone. */
    protected int slices;
    /** The number of stacks in the cone. */
    protected int stacks;
    
    /** The default constructor. */
    public jooglCone ()
    {
        super();
        radius = 1.0;
        height = 1.0;
        slices = 15;
        stacks = 5;
    }

    /** A constructor where the parameters are specified. 
     *
     * @param _radius the radius of the base of the cone.
     * @param _height the height of the cone.
     * @param _slices the number of subdivisions in base.
     * @param _stacks the number of subdivisions up the cone.
     */
    public jooglCone(double _radius, double _height, int _slices, int _stacks)
    {
        super();
        radius = _radius;
        height = _height;
        slices = _slices;
        stacks = _stacks;
    }
    
    /**
     * Set the size of the base.
     * 
     * @param _size the new size of the sphere.
     */
    public void setRadius(double _size)
    {
        radius = _size;
        redrawWindows();
    }

    /**
     * Get the size of the base.
     * 
     * @return the current size of the base.
     */
    public double getRadius()
    {
        return radius;
    }

    /**
     * Set the height of the cone.
     * 
     * @param _size the new height of the cone.
     */
    public void setHeight(double _size)
    {
        height = _size;
        redrawWindows();
    }

    /**
     * Get the height of the cone.
     * 
     * @return the current height of the cone.
     */
    public double getHeight()
    {
        return height;
    }

    /**
     * Set the slices of the base.
     * 
     * @param p the new slices of the base.
     */
    public void setSlices(int p)
    {
        slices = p;
        redrawWindows();
    }

    /**
     * Get the slices of the base.
     * 
     * @return the current slices of the base.
     */
    public int getPrecision()
    {
        return slices;
    }
    
    /**
     * Set the stackes of the height of the cone.
     * 
     * @param p the new stackes of the height of the cone.
     */
    public void setStacks(int p)
    {
        stacks = p;
        redrawWindows();
    }

    /**
     * Get the stackes of the height of the cone.
     * 
     * @return the current stackes of the height of the cone.
     */
    public int getStacks()
    {
        return stacks;
    }
    
    /** Internal function, to recreate the cone display list */
    protected void recreateDisplayList()
    {	
	gl.glNewList(dl, GL_COMPILE);
	glut.glutSolidCone(radius, height, slices, stacks);
	gl.glEndList();
    }
}
