/**
 * The drawing mode property node.
 * <p>
 * The "pickable" property infomation.   Pickable properties can be enabled and disabled
 * so that objects can be made unpickable without having to remove the property.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public class jooglPickable extends jooglProperty {
    /** Is this object pickable?   */
    protected boolean pickable;
    
    /** 
     * Create a pickable property.
     * <p>
     * The property is enabled by default.
     */ 
    public jooglPickable()
    {
        super(PROP_PICKABLE);
	pickable = false;
    }
    
    /**
     * Set the pickable property to be enabled or disabled.
     *
     * @param _pick true if the property is enabled.
     */
    public void setPickable(boolean _pick)
    {
	pickable = _pick;
    }

    /**
     * Get if the pickable property is enabled or disabled.
     *
     * @return true if the property is enabled.
     */
    public boolean getPickable()
    {
        return pickable;
    }
        
    /** 
     * Get the value of the property at time t.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return true if the property is enabled
     */
    public boolean getValue(long time)
    {
        // this is a constant property.  Override this method to create a time varying property.
        return pickable;
    }
    
    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
        // constant, do nothing
    }

    /** Internal Method, to set the OpenGL state for this property.  Called when the stacks are pushed and popped.
     *
     * Only put things here that can be called multiple times safely. 
     */
    protected void apply()
    {
    }

}
