/** 
 * The real time joogl clock object. 
 * <p>
 * This is the real time clock class.  This clock change with the system time, but can be paused and resumed.
 * Time starts at 0 when the clock is created.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglRealTimeClock extends jooglClock {
    /** The time the clock was started. */
    private long startTime = -1;
    /** Is the clock running? */
    private boolean running = true;
    
    /** The default constructor. */
    public jooglRealTimeClock ()
    {
        super();
        startTime = System.currentTimeMillis();
        time = 0;
    }
    
    /** Get the current time.
     * <p>
     * If the clock is running, the time is returned.  If the clock is paused, the start time is
     * updated so that the current time is correct based on the system time and the start time.
     *
     * @return the time in milliseconds
     */
    public long getTime()
    {
        // keep "time = System.currentTimeMillis() - startTime" by adjusting time or startTime 
        if (running)
        {
            time = System.currentTimeMillis() - startTime;
        }
        else
        {
            startTime = System.currentTimeMillis() - time;
        }
        return time;
    }

    /** Set the clock time. 
     * 
     * @param t the desired time for the clock.
     * @return the new time.
     */
    public long setTime(long t)
    {
        time = t;
        startTime = System.currentTimeMillis() - time;
        redrawWindows();
        return time;    
    }

    /**
     * Is the clock moving?
     *
     * @return true if the clock is advancing, false if paused.
     */
    public boolean isMoving()
    {
        return running;
    }
    
    /**
     * Start the clock moving.
     *
     * @return the current clock time in milliseconds
     */
    public long start()
    {
        // adjust the startTime so the clock flows from now
        startTime = System.currentTimeMillis() - time;
        // start drawing again
        redrawWindows();
        running = true;
        return time;    
    }
    
    /** 
     * Stop the clock from moving.
     *
     * @return the current time in milliseconds
     */
    public long stop()
    {
        running = false;
        // redraw one more time with correct stopped time value
        redrawWindows();
        return time;
    }
    
}
