/**
 * The shading mode property node.
 * <p>
 * The drawing mode is either FLAT or SMOOTH.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglShadeMode extends jooglProperty {
    /** Draw the object flat shaded. */
    public static final int FLAT = GL_FLAT;
    /** Draw the object smooth shaded. */
    public static final int SMOOTH = GL_SMOOTH;
    
    /** The current mode for this property. */
    protected int mode;
    
    /**
     * Create a jooglDrawMode property with the specified mode.
     * 
     * @param _mode The shading mode. 
     */
    public jooglShadeMode(int _mode)
    {
        super(PROP_SHADEMODE);
	mode = _mode;
    }
    
    /**
     * Create a jooglDrawMode property with the default mode, SMOOTH. 
     */
    public jooglShadeMode()
    {
        super(PROP_SHADEMODE);
	mode = SMOOTH;
    }
    
    /**
     * Set the mode of the property. 
     *
     * @param _mode the mode to use. 
     */
    public void setMode(int _mode)
    {
	mode = _mode;
        //redrawWindows();
    }

    /**
     * Get the mode of the property. 
     *
     * @return the current mode
     */
    public int getMode()
    {
        return mode;
    }
        
    /** 
     * Get the value of the property at time t.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return the shade mode
     */
    public int getValue(long time)
    {
        // this is a constant property.  Override this method to create a time varying property.
        return mode;
    }
        
    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
        // constant
    }

    /** Internal Method, to set the OpenGL state for this property.  Called when the stacks are pushed and popped.
     * <p>
     * Only put things here that can be called multiple times safely. 
     */
    protected void apply()
    {
        gl.glShadeModel(mode);
    }
}
